@@ -29,8 +29,3 @@ class UpImage:
             self.upyun.put(full_path, file)
             path_list.append(full_path)
         return path_list
-
-
-if __name__ == '__main__':
-    up = UpImage('mocobk', 'mocobk', 'mo123456')
-    print(up.upload())
